@@ -100,7 +100,7 @@ class ControllerMongoDB:
         finally:
             self.client.close()
 
-    def insert_many_fact(self,categorized):
+    def insert_many_fact(self):
         
         try:
             self.con_db.fact.insert_many(self.data)
@@ -108,14 +108,9 @@ class ControllerMongoDB:
         except (DuplicateKeyError, BulkWriteError) as e:
 
             self.logger.exception(e, exc_info=True)
-
-            if categorized == True:
-                self.con_db.fact.update_many(self.data,upsert=True)
-
-            else :
-                self.logger.info("Save into error colecction mongodb ")
-                self.insert_error()
-                self.logger.info("Done save into error colecction mongodb ")
+            self.logger.info("Save into error colecction mongodb ")
+            self.insert_error()
+            self.logger.info("Done save into error colecction mongodb ")
 
         except Exception as e:
             self.logger.exception(e, exc_info=True)
@@ -154,13 +149,9 @@ class ControllerMongoDB:
 
         except (DuplicateKeyError, BulkWriteError) as e:
             self.logger.error(e, exc_info=True)
-
-            if self.data['categorized'] == True:
-                self.con_db.fact.update_many(self.data,upsert=True)
-            else :
-                self.logger.info("Save into error colecction mongodb ")
-                self.insert_error()
-                self.logger.info("Done save into error colecction mongodb ")
+            self.logger.info("Save into error colecction mongodb ")
+            self.insert_error()
+            self.logger.info("Done save into error colecction mongodb ")
 
         except Exception as e:
             self.logger.error(e, exc_info=True)
