@@ -584,7 +584,7 @@ class ControllerRedShift:
                                                 transaction_uid,
                                                 user_uid,
                                                 account_uid,
-                                                ammount
+                                                amount
                                                 )
                         VALUES (%s,%s,%s,%s,%s)
                                     '''
@@ -593,7 +593,7 @@ class ControllerRedShift:
                         dict_values['transaction_uid'],
                         dict_values['user_uid'],
                         dict_values['account_uid'],
-                        dict_values['ammount']
+                        dict_values['amount']
                                 )
             cur.execute(redshift_insert_query, record_to_insert)
             
