@@ -35,9 +35,6 @@ class Summary:
         self.to_date = None
         self.set_date_range()
         
-        
-   
-        
     def set_date_range(self):
         
         self.from_date = datetime.strptime(self.from_date , '%Y-%m-%d')
@@ -46,9 +43,6 @@ class Summary:
         print("self.from_date :", self.from_date )
         print("self.to_date :", self.to_date )
         print("self.last_period", self.last_period )
-                        
-        
-
         
     def agg_master(self):
         self.query_summary_category = [
@@ -66,6 +60,7 @@ class Summary:
                  {'_id': {
                     "user_uid": "$user_uid",
                     "transaction_uid":"$_id",
+                    "currency":"$currency",
                     "lang_code":"$lang_code",
                     "country_code":"$country_code",
                     "type_flow":"$type_flow",
@@ -73,14 +68,15 @@ class Summary:
                     "description":"$source_description",
                     "created_at_homologation":"$created_at_homologation",
                     "created_at_head": "$created_at" ,
-                    "account_uid":"$account_number",
+                    "account_uid":"$account_id",
                     "bank_name":"$account_institution_name",
                     "account_type" :"$account_type",
-                    "bank_type" :"NO_DISPONIBLE",
+                    "bank_type" :"$account_institution_type",
 
                     "message_type_history":"$history-track.message_type",
                     "message_type_old":"$history-track.type" ,
 
+                    "amount" :"$amount",
                     "model_nlp_version":"$history-track.model_nlp_version", # pre
                     "model_classification_version":"$history-track.model_classification_version",
                     "model_collective_version":"$history-track.model_collective_version",
@@ -180,18 +176,11 @@ class Summary:
                     "person_uid_def_collect":"$history-track.details.person_uid_def_collect",
                     "special_moment_uid_def_collect":"$history-track.details.special_moment_uid_def_collect",
                     "subcat_uid_def_collect":"$history-track.details.subcategory_uid_def_collect",
-                      
-
                        },
                 'count': {"$sum": 1}
                 }
-
-             
             }
-            
         ]
-
-        
        
         return pd.json_normalize(pd.DataFrame(list( self.MongoDB.con_db.aggregate(self.query_summary_category) ))['_id']) 
 
@@ -211,7 +200,6 @@ s = Summary(front_date,num_days = 240)
 r = s.agg_master()
 
 
-
 r['business_uid_def_usr'] = r['business_uid_def_usr'].apply(lambda x: x) + r['business_uid_def_usr_'].apply(lambda x: x) + r['business_uid_def_usr_info'].apply(lambda x: x)
 
 del r['business_uid_def_usr_']
@@ -328,9 +316,6 @@ for idx ,item in enumerate(r.to_dict(orient='records')):
 
     if not item['created_at_head'] or item['created_at_head'] is pd.NaT:
         item['created_at_head'] = datetime.strptime('2000-01-01T00:00:00',format_inter).replace(microsecond=0).isoformat()
-
-       
-        
         
     if not transaction_dict['classified_at']:
         transaction_dict['classified_at'] = datetime.strptime('2000-01-01T00:00:00',format_inter).replace(microsecond=0).isoformat()
@@ -372,6 +357,9 @@ for idx ,item in enumerate(r.to_dict(orient='records')):
                 "postcode":None
                 }
     
+    if not 'account_uid' in item:
+        item['account_uid'] = '123'
+    
     if item['account_uid'] is None:
         item['account_uid'] = '123'
 
@@ -406,7 +394,8 @@ for idx ,item in enumerate(r.to_dict(orient='records')):
     fact_transactions_dict['transaction_uid'] = item['transaction_uid']
     fact_transactions_dict['user_uid'] = item['user_uid']
     fact_transactions_dict['account_uid'] = item['account_uid']
-    fact_transactions_dict['ammount'] = 0.0
+    fact_transactions_dict['amount'] = item['amount']
+
 
  
     print("\nfact_transactions_dict: ")
